@@ -15,9 +15,12 @@ class SeparateSearchAdmin(admin.ModelAdmin):
         """"""
         if hasattr(self, "search_form"):
             self.advanced_search_fields = {}
-            self.search_form_data = self.search_form(request.GET)
-            self.extract_advanced_search_terms(request.GET)
-            extra_context = {"separate_search_fields": self.search_form_data}
+            self.extract_advanced_search_terms(request)
+            self.search_form_data = self.search_form(initial=self.get_request_query_values(request))
+            extra_context = {
+                "separate_search_fields": self.search_form_data,
+                "query_params": self.get_request_query_values(request),
+            }
 
         return super().changelist_view(request, extra_context=extra_context)
 
@@ -25,15 +28,16 @@ class SeparateSearchAdmin(admin.ModelAdmin):
         """
         allow to extract field values from request
         """
-        request._mutable = True  # pylint: disable=protected-access
+        request.GET._mutable = True  # pylint: disable=protected-access
 
-        if self.search_form_data is not None:
-            for key in self.search_form_data.fields.keys():
-                temp = request.pop(key, None)
+        request_form_data = self.search_form(request.GET)
+        if request_form_data is not None:
+            for key in request_form_data.fields.keys():
+                temp = request.GET.pop(key, None)
                 if temp and (type(temp) == list and temp[0]):  # there is a field but it's empty so it's useless
                     self.advanced_search_fields[key] = temp
 
-        request._mutable = False  # pylint: disable=protected-access
+        request.GET._mutable = False  # pylint: disable=protected-access
 
     def get_queryset(self, request):
         """
@@ -68,27 +72,33 @@ class SeparateSearchAdmin(admin.ModelAdmin):
 
         return False, None
 
-    @staticmethod
-    def get_field_value_default(field, form_field, field_value, has_field_value, request):
+    def get_field_value_json(self, field, form_field, field_value):
+        field_name = form_field.widget.attrs.get("filter_field", field)
+        field_filter = field_name + form_field.widget.attrs.get("filter_method", "")
+
+        field_value = format_data(form_field, field_value)
+
+        return {field_filter: field_value}
+
+    def get_field_value_default(self, field, form_field, field_value, has_field_value, request):
         """
         mount default field value
         """
         if has_field_value:
             field_name = form_field.widget.attrs.get("filter_field", field)
-            field_filter = field_name + form_field.widget.attrs.get("filter_method", "")
 
             try:
-                field_value = format_data(form_field, field_value)  # format by field type
-                return Q(**{field_filter: field_value})
+                field_val_json = self.get_field_value_json(field, form_field, field_value)
+                return Q(**field_val_json)
             except ValidationError:
                 messages.add_message(
                     request,
                     messages.ERROR,
-                    _(f"Filter in field `{field_name}` ignored, because value `{field_value}` isn't valid"),
+                    _(f"Filter in field '{field_name}' ignored, because value '{field_value}' isn't valid"),
                 )
             except Exception:  # pylint: disable=broad-except
                 messages.add_message(
-                    request, messages.ERROR, _(f"Filter in field `{field_name}` ignored, error has occurred.")
+                    request, messages.ERROR, _(f"Filter in field '{field_name}' ignored, error has occurred.")
                 )
 
         return Q()
@@ -103,3 +113,15 @@ class SeparateSearchAdmin(admin.ModelAdmin):
             )
 
         return self.get_field_value_default(field, form_field, field_value, has_field_value, request)
+
+    def get_request_query_values(self, request):
+        resp = {}
+        request_form_data = self.search_form(request.GET)
+
+        for field, form_field in request_form_data.fields.items():
+            has_field_value, field_value = self.get_request_field_value(field)
+            if has_field_value:
+                field_value_json = self.get_field_value_json(field, form_field, format_data(form_field, field_value))
+                resp = {**resp, **field_value_json}
+
+        return resp
